@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.107 2006/07/24 17:24:20 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.113 2006/10/01 14:37:28 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -50,9 +50,9 @@ char *base_desc[]  = {         /* Tooltips for each base value. */
 
 char *calc_res[] = {
     "accuracy", "base", "display", "modetype", "showregisters", "trigtype",
-    "showzeroes", "showthousands", "syntax",
+    "showzeroes", "showthousands", "syntax", "xposition", "yposition",
     "register0", "register1", "register2", "register3", "register4",
-    "register5", "register6", "register7", "register8", "register9"
+    "register5", "register6", "register7", "register8", "register9", "bitcalculating"
 };
 
 char *dtype_str[] = {          /* Strings for each display mode value. */
@@ -95,6 +95,7 @@ char *Rmstr[MAXMODES]     = { "BASIC", "ADVANCED", "FINANCIAL",
                               "SCIENTIFIC" };
 char *Rtstr[MAXTRIGMODES] = { "DEG", "GRAD", "RAD" };
 char *Rsstr[MAXSYNTAX]    = { "ARITHMETIC", "ARITHMETIC_PRECEDENCE" };
+char *Rcstr[MAXBITCALC]   = { "NO_BITCALCULATING_MODE", "BITCALCULATING_MODE" };
 
 
 /* Valid keys when an error condition has occured. */
@@ -388,7 +389,7 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     { GDK_percent, 0 },
     '%',
     M_NONE,
-    do_calc,  
+    do_percent,  
     NULL,
     immediate
 },
@@ -1231,10 +1232,20 @@ doerr(char *errmes)
     if (!v->started) {
         return;
     }
-    STRCPY(v->display, errmes);
-    set_error_state(TRUE);
-    set_display(v->display, FALSE);
-    beep();
+
+    switch (v->syntax) {
+        case npa:
+            strncpy(v->display, errmes, MAXLINE - 1);
+            v->display[MAXLINE - 1] = '\0';
+            set_error_state(TRUE);
+            set_display(v->display, FALSE);
+            beep();
+            break;
+
+        case exprs:
+            v->math_error = -MPMATH_ERR;
+            break;
+    }
 }
 
 
