@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.79 2006/03/27 21:06:21 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.84 2006/09/22 15:22:20 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -74,9 +74,10 @@ enum num_type { ENG, FIX, SCI };            /* Number display mode. */
 
 /* Resources. */
 enum res_type { R_ACCURACY, R_BASE, R_DISPLAY, R_MODE, R_REGS, R_TRIG,
-                R_ZEROES,   R_TSEP, R_SYNTAX, 
+                R_ZEROES,   R_TSEP, R_SYNTAX,  R_XPOS, R_YPOS,
                 R_REG0,     R_REG1, R_REG2,    R_REG3, R_REG4,
-                R_REG5,     R_REG6, R_REG7,    R_REG8, R_REG9
+                R_REG5,     R_REG6, R_REG7,    R_REG8, R_REG9,
+				R_BITCALC
 };
 
 enum trig_type { DEG, GRAD, RAD };          /* Trigonometric types. */
@@ -194,6 +195,7 @@ enum trig_func {SIN=0, COS=1, TAN=2};
 #define MAXTRIGMODES   3          /* Maximum number of trig. modes. */
 #define MAXVKEYS       1          /* Number of valid keys after an error. */
 #define MAXSYNTAX      2          /* Number of syntaxes in calculator */
+#define MAXBITCALC     2          /* Choices for bitcalculating */
 
 #define MCOLS          8          /* Number of columns of "special" keys. */
 #define MROWS          2          /* Number of rows of "special" keys. */
@@ -226,6 +228,8 @@ enum trig_func {SIN=0, COS=1, TAN=2};
 
 #define UNDO_HISTORY_LENGTH 16  /* Arithmetic mode undo history length */
 
+#define MPMATH_ERR		    	20001
+
 typedef unsigned long  BOOLEAN;
 
 enum button_flags {
@@ -347,6 +351,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int doing_mi;      /* Set if adjusting the "show zeroes" menu item. */
     int down;          /* Indicates is a mouse button is down. */
     int error;         /* Indicates some kind of display error. */
+    int math_error;    /* Math error (used in expression mode) */
     int hyperbolic;    /* If set, trig functions will be hyperbolic. */
     int iconic;        /* Set if window is currently iconic. */
     int inverse;       /* If set, trig and log functions will be inversed. */
@@ -369,6 +374,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int started;       /* Set just before window is displayed. */
     int toclear;       /* Indicates if display should be cleared. */
     int warn_change_mode;    /* Should we warn user when changing modes? */
+    int bitcalculating_mode;  /* 0 = no, else yes */
 };
 
 typedef struct calcVars *Vars;
@@ -408,6 +414,7 @@ int char_val(char);
 int do_rcl_reg(int reg, int value[MP_SIZE]);
 int do_sto_reg(int reg, int value[MP_SIZE]);
 int do_tfunc(int s[MP_SIZE], int t[MP_SIZE], enum trig_func tfunc);
+int get_int_resource(enum res_type, int *);
 int get_menu_entry(enum menu_type, int);
 int key_equal(struct button *, struct button);
 int main(int, char **);
@@ -438,6 +445,7 @@ void do_point();
 void do_portion();
 void do_trig();
 void do_trigtype(enum trig_type);
+void do_percent();
 void doerr(char *);
 void exp_del();
 void get_constant(int);
