@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.82 2006/08/09 16:54:01 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.86 2006/09/29 18:06:29 sampie Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -138,9 +138,6 @@ new_state(void)
 	v->h.begin = ((v->h.begin + 1) % UNDO_HISTORY_LENGTH);
     }
 
-    //purge_redo_history();
-
-    assert(!v->h.e[v->h.current].expression);
     copy_state(&(v->h.e[v->h.current]), &(v->h.e[c]));
     update_undo_redo_button_sensitivity();
 }
@@ -158,6 +155,12 @@ perform_undo(void)
     update_undo_redo_button_sensitivity();
 }
 
+int
+is_undo_step()
+{
+  return (v->h.current != v->h.begin);
+}
+
 void
 perform_redo(void)
 {
@@ -254,7 +257,7 @@ exp_del()
 }
 
 
-static int 
+int 
 usable_num(int MPnum[MP_SIZE]) 
 {
     int ret = 0;
@@ -507,36 +510,41 @@ do_expression()
     } else if (e->button.flags & inv) {
         exp_inv();
     } else if (e->button.flags & enter) {
-        if (e->expression) {
+	  if (e->expression) {
 	    if (strcmp(e->expression, "Ans")) {
-		    int MPval[MP_SIZE];
-		    int ret = ce_parse(e->expression, MPval);
-		    if (!ret) {
+		  int MPval[MP_SIZE];
+		  int ret = ce_parse(e->expression, MPval);
+		  if (!ret) {
 			mpstr(MPval, e->ans);
 			exp_replace("Ans");
-		    } else {
+		  } else {
 			char *message = NULL;
 			switch (ret) {
 			case -PARSER_ERR_INVALID_BASE:
-			    message = _("Invalid number for the current base");
-			    break;
+			  message = _("Invalid number for the current base");
+			  break;
 			case -PARSER_ERR_TOO_LONG_NUMBER:
-			    message = _("Too long number");
-			    break;
+			  message = _("Too long number");
+			  break;
 			case -PARSER_ERR_BITWISEOP:
-			    message = _("Invalid bitwise operation parameter(s)");
-			    break;
+			  message = _("Invalid bitwise operation parameter(s)");
+			  break;
+			case -MPMATH_ERR:
+			  message = _("Math operation error");
+			  break;
 			default:
-			    message = _("Malformed expression");
-			    break;
+			  message = _("Malformed expression");
+			  break;
 			}
 			update_statusbar(message, "gtk-dialog-error");
-		    }
+		  }
 	    } else {
-		perform_undo();
-		perform_undo();
+		  perform_undo();
+		  if (is_undo_step()) {
+			perform_undo();
+		  }
 	    }
-	}
+	  }
     } else {
 	exp_append(btext);
 	if (e->button.flags & func) {
@@ -604,11 +612,6 @@ do_calc()      /* Perform arithmetic calculation and display result. */
         mpmul(MP1, v->MPdisp_val, MP2);
         mpsub(v->MPresult, MP2, v->MPresult);
 
-    } else if (IS_KEY(v->cur_op, KEY_PER.value[0])) {     /* % */
-        mpmul(v->MPresult, v->MPdisp_val, v->MPresult);
-        MPstr_to_num("0.01", DEC, MP1);
-        mpmul(v->MPresult, MP1, v->MPresult);
-
     } else if (IS_KEY(v->cur_op, KEY_YTOX.value[0])) {    /* y^x */
         calc_xpowy(v->MPresult, v->MPdisp_val, v->MPresult);
 
@@ -691,6 +694,14 @@ do_trig()
 }
 
 
+void
+do_percent()
+{
+  calc_percent(v->MPdisp_val, v->MPresult);
+  show_display(v->MPresult);
+  mpstr(v->MPresult, v->MPdisp_val);
+}
+
 int
 do_tfunc(int s[MP_SIZE], int t[MP_SIZE], enum trig_func tfunc)
 {
